SWDEV-341956 - update HIP Dtest with correct coordinates (#2755)

Change-Id: Iaccc4251a984e690d680ce884c6bfcc1093703af
Dieser Commit ist enthalten in:
ROCm CI Service Account
2022-06-30 13:29:27 +05:30
committet von GitHub
Ursprung 84c23e2b41
Commit 2667f3e225
11 geänderte Dateien mit 24 neuen und 24 gelöschten Zeilen
+1 -1
Datei anzeigen
@@ -34,7 +34,7 @@ DECLARE_DATA();
__global__ void print_things() {
DECLARE_DATA();
uint tid = hipThreadIdx_x + hipBlockIdx_x * hipBlockDim_x;
uint tid = threadIdx.x + blockIdx.x * blockDim.x;
const char *msg[] = {msg_short, msg_long1, msg_long2};
printf("%s\n", msg[tid % 3]);